==> Xarm-1.2.7.tar.gz: Xarm-1.2.7/include/Xarm/Display.h <==
/* $Id: Display.h,v 1.1.1.1 1997/03/19 13:32:20 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_DISPLAY_H_)
#define _XARM_DISPLAY_H_

/* ======================================================================= */
/* Include(s): */
#include <Xarm/ApplicationS.h>

class DisplayClass;
typedef DisplayClass *WDisplay;
WDisplay getWDisplay(Display *);

class DisplayClass : public ApplicationShellClass {
 protected:
   friend WDisplay getWDisplay(Display *);
   DisplayClass() {} /* only a derived class can make this */

   virtual WidgetClass classPointer() { return xmDisplayClass; }
   virtual _XtString className() { return (_XtString) "XmDisplay"; }
 public:
   /* resources */

#if defined(HAVE_DVB)
   /* well this seems to be missing in Motif 1.2.3 */
   void defaultVirtualBindings(_XtString);
   _XtString defaultVirtualBindings();
#endif

   void dragInitiatorProtocolStyle(unsigned char);
   unsigned char dragInitiatorProtocolStyle();
   void dragReceiverProtocolStyle(unsigned char);
   unsigned char dragReceiverProtocolStyle();
};


#endif

==> Xarm-1.3.1.tar.gz: Xarm-1.3.1/include/Xarm/Display.h <==
/* $Id: Display.h,v 1.2 1999/01/15 09:38:42 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_DISPLAY_H_)
#define _XARM_DISPLAY_H_

/* ======================================================================= */
/* Include(s): */
#include <Xarm/ApplicationS.h>

class DisplayClass;
typedef DisplayClass *WDisplay;
WDisplay getWDisplay(Display *);

class DisplayClass : public ApplicationShellClass {
 protected:
   friend WDisplay getWDisplay(Display *);
   DisplayClass() {} /* only a derived class can make this */

   virtual WidgetClass classPointer() { return xmDisplayClass; }
   virtual _XtString className() { return (_XtString) "XmDisplay"; }
 public:
   /* resources */

#if defined(HAVE_DVB)
   /* well this seems to be missing in Motif 1.2.3 */
   void defaultVirtualBindings(const _XtString);
   _XtString defaultVirtualBindings();
#endif

   void dragInitiatorProtocolStyle(unsigned char);
   unsigned char dragInitiatorProtocolStyle() const;
   void dragReceiverProtocolStyle(unsigned char);
   unsigned char dragReceiverProtocolStyle() const;
};


#endif
